==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/link/lang/eo.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'eo', {
	acccessKey: 'Fulmoklavo',
	advanced: 'Speciala',
	advisoryContentType: 'Enhavotipo',
	advisoryTitle: 'Priskriba Titolo',
	anchor: {
		toolbar: 'Ankro',
		menu: 'Enmeti/Ŝanĝi Ankron',
		title: 'Ankraj Atributoj',
		name: 'Ankra Nomo',
		errorName: 'Bv entajpi la ankran nomon',
		remove: 'Forigi Ankron'
	},
	anchorId: 'Per Elementidentigilo',
	anchorName: 'Per Ankronomo',
	charset: 'Signaro de la Ligita Rimedo',
	cssClasses: 'Klasoj de Stilfolioj',
	emailAddress: 'Retpoŝto',
	emailBody: 'Mesaĝa korpo',
	emailSubject: 'Mesaĝa Temo',
	id: 'Id',
	info: 'Informoj pri la Ligilo',
	langCode: 'Lingva Kodo',
	langDir: 'Skribdirekto',
	langDirLTR: 'De maldekstro dekstren (LTR)',
	langDirRTL: 'De dekstro maldekstren (RTL)',
	menu: 'Ŝanĝi Ligilon',
	name: 'Nomo',
	noAnchors: '<Ne disponeblas ankroj en la dokumento>',
	noEmail: 'Bonvolu entajpi la retpoŝtadreson',
	noUrl: 'Bonvolu entajpi la URL-on',
	other: '<alia>',
	popupDependent: 'Dependa (Netscape)',
	popupFeatures: 'Atributoj de la Ŝprucfenestro',
	popupFullScreen: 'Tutekrane (IE)',
	popupLeft: 'Maldekstra Pozicio',
	popupLocationBar: 'Adresobreto',
	popupMenuBar: 'Menubreto',
	popupResizable: 'Dimensiŝanĝebla',
	popupScrollBars: 'Rulumskaloj',
	popupStatusBar: 'Statobreto',
	popupToolbar: 'Ilobreto',
	popupTop: 'Supra Pozicio',
	rel: 'Rilato',
	selectAnchor: 'Elekti Ankron',
	styles: 'Stilo',
	tabIndex: 'Taba Indekso',
	target: 'Celo',
	targetFrame: '<kadro>',
	targetFrameName: 'Nomo de CelKadro',
	targetPopup: '<ŝprucfenestro>',
	targetPopupName: 'Nomo de Ŝprucfenestro',
	title: 'Ligilo',
	toAnchor: 'Ankri en tiu ĉi paĝo',
	toEmail: 'Retpoŝto',
	toUrl: 'URL',
	toolbar: 'Enmeti/Ŝanĝi Ligilon',
	type: 'Tipo de Ligilo',
	unlink: 'Forigi Ligilon',
	upload: 'Alŝuti'
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/eo.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'eo', {
	acccessKey: 'Fulmoklavo',
	advanced: 'Speciala',
	advisoryContentType: 'Enhavotipo',
	advisoryTitle: 'Priskriba Titolo',
	anchor: {
		toolbar: 'Ankro',
		menu: 'Enmeti/Ŝanĝi Ankron',
		title: 'Ankraj Atributoj',
		name: 'Ankra Nomo',
		errorName: 'Bv entajpi la ankran nomon',
		remove: 'Forigi Ankron'
	},
	anchorId: 'Per Elementidentigilo',
	anchorName: 'Per Ankronomo',
	charset: 'Signaro de la Ligita Rimedo',
	cssClasses: 'Klasoj de Stilfolioj',
	download: 'Altrudi Elŝuton',
	displayText: 'Vidigi Tekston',
	emailAddress: 'Retpoŝto',
	emailBody: 'Mesaĝa korpo',
	emailSubject: 'Mesaĝa Temo',
	id: 'Id',
	info: 'Informoj pri la Ligilo',
	langCode: 'Lingva Kodo',
	langDir: 'Skribdirekto',
	langDirLTR: 'De maldekstro dekstren (LTR)',
	langDirRTL: 'De dekstro maldekstren (RTL)',
	menu: 'Ŝanĝi Ligilon',
	name: 'Nomo',
	noAnchors: '<Ne disponeblas ankroj en la dokumento>',
	noEmail: 'Bonvolu entajpi la retpoŝtadreson',
	noUrl: 'Bonvolu entajpi la URL-on',
	noTel: 'Please type the phone number', // MISSING
	other: '<alia>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependa (Netscape)',
	popupFeatures: 'Atributoj de la Ŝprucfenestro',
	popupFullScreen: 'Tutekrane (IE)',
	popupLeft: 'Maldekstra Pozicio',
	popupLocationBar: 'Adresobreto',
	popupMenuBar: 'Menubreto',
	popupResizable: 'Dimensiŝanĝebla',
	popupScrollBars: 'Rulumskaloj',
	popupStatusBar: 'Statobreto',
	popupToolbar: 'Ilobreto',
	popupTop: 'Supra Pozicio',
	rel: 'Rilato',
	selectAnchor: 'Elekti Ankron',
	styles: 'Stilo',
	tabIndex: 'Taba Indekso',
	target: 'Celo',
	targetFrame: '<kadro>',
	targetFrameName: 'Nomo de CelKadro',
	targetPopup: '<ŝprucfenestro>',
	targetPopupName: 'Nomo de Ŝprucfenestro',
	title: 'Ligilo',
	toAnchor: 'Ankri en tiu ĉi paĝo',
	toEmail: 'Retpoŝto',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Enmeti/Ŝanĝi Ligilon',
	type: 'Tipo de Ligilo',
	unlink: 'Forigi Ligilon',
	upload: 'Alŝuti'
} );
